# NSIS

To use this language, use the class "language-nsis".

## Comments

    ; Single line comment
    # Single line comment
    /* Multi-line
    comment */

## Strings

    "foo \"bar\" baz"
    'foo \'bar\' baz'

## Variables

    LicenseLangString myLicenseData ${LANG_ENGLISH} "bigtest.nsi"
    LicenseData $(myLicenseData)
    StrCmp $LANGUAGE ${LANG_ENGLISH} 0 +2

## Compiler commands

    !define VERSION "1.0.3"
    !insertmacro MyFunc ""

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Comment-like substrings

    "foo /* bar */ baz"
    "foo ; bar";